﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;

namespace XamDataTree
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        public ObservableCollection<SimpleNode> Nodes { get; set; }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            List<SimpleNode> simpleNodes = CreateSimpleNodes();
            Nodes = new ObservableCollection<SimpleNode>(simpleNodes);
            xamDataTree1.ItemsSource = Nodes;
        }

        private static List<SimpleNode> CreateSimpleNodes()
        {
            List<SimpleNode> simpleNodes = new List<SimpleNode>();
            for (int i = 0; i < 20; i++)
            {
                SimpleNode topNode = CreateNode(0, i);

                List<SimpleNode> level1Nodes = new List<SimpleNode>();
                for (int j = 0; j < 10; j++)
                {
                    SimpleNode secondNode = CreateNode(1, j);

                    List<SimpleNode> level2Nodes = new List<SimpleNode>();
                    for (int k = 0; k < 2; k++)
                    {
                        SimpleNode thirdNode = CreateNode(2, k);
                        level2Nodes.Add(thirdNode);
                    }
                    secondNode.Children = new ObservableCollection<SimpleNode>(level2Nodes);

                    level1Nodes.Add(secondNode);
                }
                topNode.Children = new ObservableCollection<SimpleNode>(level1Nodes);

                simpleNodes.Add(topNode);

            }
            return simpleNodes;
        }

        private static SimpleNode CreateNode(int i, int level)
        {
            SimpleNode sn = new SimpleNode()
            {
                Name = string.Format("Node {0}-{1}", i, level),
                IsExpanded = false,
                IsChecked = false
            };
            return sn;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //Create new node
            List<string> selectedNames = GetSelectedNames(Nodes);
            List<SimpleNode> newNodes = CreateSimpleNodes();
            //Select nodes that where selected
            foreach (string selected in selectedNames)
            {
                SimpleNode node = SimpleNode.FindNode(newNodes, selected);
                if (node != null)
                    node.IsChecked = true;
            }

            Nodes = new ObservableCollection<SimpleNode>(newNodes);
            xamDataTree1.ItemsSource = Nodes;

        }

        private List<string> GetSelectedNames(IEnumerable<SimpleNode> nodes)
        {
            List<string> result = new List<string>();

            if (nodes != null)
            {
                foreach (SimpleNode node in nodes)
                {
                    if (node.IsChecked)
                        result.Add(node.Name);
                    result.AddRange(GetSelectedNames(node.Children));
                }
            }
            return result;
        }
    }
}
