﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Collections.Generic;

namespace XamDataTree
{
    public class SimpleNode : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private string _name;
        public string Name
        {
            get { return _name; }
            set
            {
                if (_name != value)
                {
                    _name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        private bool _isExpanded;
        public bool IsExpanded
        {
            get { return _isExpanded; }
            set
            {
                if (_isExpanded != value)
                {
                    _isExpanded = value;
                    OnPropertyChanged("IsExpanded");
                }
            }
        }

        private bool _isChecked;
        public bool IsChecked
        {
            get { return _isChecked; }
            set
            {
                if (_isChecked != value)
                {
                    _isChecked = value;
                    OnPropertyChanged("IsChecked");
                }
            }
        }

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        private ObservableCollection<SimpleNode> _children;
        /// <summary>
        /// Gets children nodes.
        /// </summary>
        public ObservableCollection<SimpleNode> Children
        {
            get { return _children; }
            set
            {
                _children = value;
            }
        }

        public static SimpleNode FindNode(IEnumerable<SimpleNode> nodes, string name)
        {
            if (nodes == null)
                return null;
            SimpleNode result = null;
            foreach (SimpleNode node in nodes)
            {
                if (node.Name == name)
                    return node;
                return FindNode(node.Children, name);                
            }
            return null;
        }
    }
}
